@@ -455,9 +455,11 @@ valid_mime_type (const char *name,
 
 	name_ext = get_filename_extension (name);
 	if ((name_ext != NULL) && (strcmp (name_ext, "") != 0)) {
-		const char *exts[] = { "JPG", "JPEG", "PNG", "TIF", "TIFF", "GIF",
-				       "AVI", "MPG", "MPEG",
-				       "AU", "WAV", "OGG", "MP3", "FLAC" };
+		const char *exts[] = { "JPG", "JPEG", "PNG", "TIF", "TIFF", "GIF",	/* images */
+				       "CR2", "CRW", "RAF", "DCR", "MOS", "RAW", "DNG", /* RAW images */
+				       "XCF", "SRF", "ORF", "MRW", "NEF", "PEF", "ARW", /* RAW images */
+				       "AVI", "MPG", "MPEG",				/* video */
+				       "AU", "WAV", "OGG", "MP3", "FLAC" };		/* audio */
 		for (i = 0; i < G_N_ELEMENTS (exts); i++) {
 			const char *ext = exts[i];
 			if (strncasecmp (ext, name_ext, strlen (name_ext)) == 0)
@@ -1395,13 +1397,14 @@ adjust_orientation__step (AsyncOperationData *aodata,
 			  DialogData         *data)
 {
 	const char       *filepath = aodata->scan->data;
-	GnomeVFSFileInfo  info;
+	GnomeVFSFileInfo *info;
 	GtkWindow        *window = GTK_WINDOW (data->dialog);
 
-	gnome_vfs_get_file_info (filepath, &info, GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS|GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
+	info = gnome_vfs_file_info_new();
+	gnome_vfs_get_file_info (filepath, info, GNOME_VFS_FILE_INFO_GET_ACCESS_RIGHTS|GNOME_VFS_FILE_INFO_FOLLOW_LINKS);
 
 	if (file_is_image (filepath, TRUE)) {
-		FileData     *fd = file_data_new (filepath, &info);
+		FileData     *fd = file_data_new (filepath, info);
 		GthTransform transform = read_orientation_field (fd->path);
 		if (image_is_jpeg (filepath))
 			apply_transformation_jpeg (window, fd->path, transform);
@@ -1411,7 +1414,8 @@ adjust_orientation__step (AsyncOperationData *aodata,
 		file_data_unref (fd);
 	}
 
-	gnome_vfs_set_file_info (filepath, &info, GNOME_VFS_SET_FILE_INFO_PERMISSIONS|GNOME_VFS_SET_FILE_INFO_OWNER);
+	gnome_vfs_set_file_info (filepath, info, GNOME_VFS_SET_FILE_INFO_PERMISSIONS|GNOME_VFS_SET_FILE_INFO_OWNER);
+	gnome_vfs_file_info_unref(info); 
 }
 
 
@@ -1964,7 +1968,7 @@ dlg_photo_importer (GthBrowser *browser)
 
 	default_path = eel_gconf_get_path (PREF_PHOTO_IMPORT_DESTINATION, NULL);
 	if ((default_path == NULL) || (*default_path == 0))
-		default_path = g_strdup (g_get_home_dir());
+		default_path = xdg_user_dir_lookup ("PICTURES");
 	gtk_file_chooser_set_uri (GTK_FILE_CHOOSER (data->destination_filechooserbutton), default_path);
 	g_free (default_path);
 
